DocumentPickOptions class

Options for picking document files.

Supports:

  • single/multiple selection
  • custom extensions

Constructors

DocumentPickOptions({bool allowMultiple = false, List<String>? extensions})
const

Properties

allowMultiple bool
Whether multiple documents can be selected
final
defaultExtensions List<String>
Default supported document formats
no setter
extensions List<String>?
Optional custom extensions
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited