ImagePickOptions class

Options for picking an image.

Allows specifying:

  • source (camera/gallery)
  • image compression quality

Constructors

ImagePickOptions({ImageSource source = ImageSource.gallery, int? quality})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
quality int?
Optional compression quality (1–100)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source → ImageSource
Source of image (camera or gallery)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited